Name:           libdigidocpp
Version:        3.12.3
Release:        2%{?dist}
Summary:        Library for creating and validating BDoc and DDoc containers
License:        LGPLv2+
URL:            https://github.com/open-eid/libdigidocpp
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz

# only for f26 and higher
%if 0%{?fedora} >= 26
Patch0:         libdigidocpp-opensslv1.1.patch
%endif

BuildRequires:  cmake
BuildRequires:  libdigidoc-devel
BuildRequires:  openssl-devel
BuildRequires:  xml-security-c-devel
BuildRequires:  xsd
BuildRequires:  minizip-devel
# Provide xxd
BuildRequires:  vim-common

# Dynamically loaded libraries
Requires:       opensc%{?_isa}

%description
libdigidocpp is a C++ library for reading, validating, and creating BDoc and
DDoc containers. These file formats are widespread in Estonia where they are
used for storing legally binding digital signatures.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       libdigidoc-devel
Requires:       openssl-devel
Requires:       xml-security-c-devel
Requires:       xsd

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Requires:       %{name} = %{version}-%{release}

%description    doc
The %{name}-doc package contains documentation provided by upstream.

%prep
%setup -q

# Use this patch only for F26 and upwards
%if 0%{?fedora} >= 26
%patch0 -p1
%endif


# Remove bundled minizip
rm -rf src/minizip
# Remove bundled openssl
rm -rf src/openssl

%build
%{cmake} . \
 -DCMAKE_INSTALL_SYSCONFDIR=/etc \
 -DSWIG_EXECUTABLE=SWIG_EXECUTABLE-NOTFOUND

make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}

%check

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc AUTHORS COPYING README.md CONTRIBUTING.md RELEASE-NOTES.txt LICENSE.LGPL
%{_libdir}/*.so.*
%dir %{_sysconfdir}/digidocpp
%config(noreplace) %{_sysconfdir}/digidocpp/digidocpp.conf
%{_sysconfdir}/digidocpp/878252.p12
%{_sysconfdir}/digidocpp/schema/
%{_bindir}/digidoc-*
%{_mandir}/man1/digidoc-tool.1.*

%files devel
%doc AUTHORS COPYING README.md CONTRIBUTING.md RELEASE-NOTES.txt LICENSE.LGPL
%{_includedir}/digidocpp/
%{_libdir}/pkgconfig/lib*.pc
%{_libdir}/*.so

%files doc
%doc AUTHORS COPYING README.md CONTRIBUTING.md RELEASE-NOTES.txt LICENSE.LGPL doc/*



%changelog
* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.12.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 24 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.3-1
- New upstream release
- Add openssl v1.1 support via libdigidocpp-opensslv1.1.patch
- Remove bundled openssl

* Sun Feb 19 2017 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.2-3
- Remove bundled minizip

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.12.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sun Jul 10 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.2-1
- New upstream release

* Thu May 19 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.1-1
- New upstream release

* Tue Feb 02 2016 Mihkel Vain <mihkel@fedoraproject.org> - 3.12.0-1
- New upstream release

* Tue Sep 22 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.11.1.1306-1
- New upstream release

* Mon Jul 13 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.11.0.1296-1
- New upstream release
- Spec file cleanups

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Apr 19 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.10.0-2
- Rebuild for gcc5

* Sat Mar 28 2015 Mihkel Vain <mihkel@fedoraproject.org> - 3.10.0-1
- New upstream release
- Project moved to github

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9.0.1237-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul  3 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.9.0.1237-1
- New upstream release
- Create a separate sub-package for docs

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.0.1208-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 18 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.8.0.1208-3
- Fix typo: ppython-digidoc -> python-digidoc

* Wed Apr 30 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.8.0.1208-2
- Use cmake macro
- Obsolete old subpackages

* Thu Apr 24 2014 Mihkel Vain <mihkel@fedoraproject.org> - 3.8.0.1208-1
- First package based on new source code from RIA

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 0.3.0-19
- Perl 5.18 rebuild

* Fri Mar 22 2013 Remi Collet <rcollet@redhat.com> - 0.3.0-18
- rebuild for http://fedoraproject.org/wiki/Features/Php55

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jun 07 2012 Petr Pisar <ppisar@redhat.com> - 0.3.0-15
- Perl 5.16 rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-14
- Rebuilt for c++ ABI breakage

* Thu Jan 19 2012 Remi Collet <remi@fedoraproject.org> - 0.3.0-13
- build against php 5.4.0
- add %%check for php extension
- %%config flag for digidoc.ini

* Thu Jan 19 2012 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.3.0-12
- Add libdigidocpp-0.3.0-gcc47.patch (Fix mass rebuild FTBFS).

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jul 22 2011 Petr Pisar <ppisar@redhat.com> - 0.3.0-10
- RPM 4.9 dependency filtering added

* Mon Jun 20 2011 Petr Sabata <contyk@redhat.com> - 0.3.0-9
- Perl mass rebuild
- Removing now obsolete Buildroot and defattr

* Fri Apr 15 2011 Kalev Lember <kalev@smartlink.ee> - 0.3.0-8
- Rebuilt for lib11 0.2.8 soname bump

* Wed Mar 16 2011 Antti Andreimann <Antti.Andreimann@mail.ee> 0.3.0-7
- Rebuilt with xml-security-c 1.6.0

* Thu Mar 10 2011 Kalev Lember <kalev@smartlink.ee> - 0.3.0-6
- Cleaned up php conditionals not needed in current Fedora releases

* Thu Mar 10 2011 Kalev Lember <kalev@smartlink.ee> - 0.3.0-5
- Rebuilt with xerces-c 3.1

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Oct 20 2010 Kalev Lember <kalev@smartlink.ee> - 0.3.0-3
- Updated descriptions for bindings subpackages, thanks to Sander Lepik.

* Tue Oct 12 2010 Kalev Lember <kalev@smartlink.ee> - 0.3.0-2
- Remove bundled minizip in prep

* Mon Oct 11 2010 Kalev Lember <kalev@smartlink.ee> - 0.3.0-1
- Update to 0.3.0
- Renamed binding subpackages to use <language>-digidoc naming scheme
- Filter shared object provides in private directories
- Added missing defattr lines
- Marked digidocpp.conf as noreplace

* Thu Jul 01 2010 Antti Andreimann <Antti.Andreimann@mail.ee> - 0.2.0-0.7.svn2811
- Added language bindings for Python, Perl and PHP

* Mon Mar 29 2010 Kalev Lember <kalev@smartlink.ee> - 0.2.0-0.6.svn2681
- Spec file clean up
- Updated summary
- Removed BR: pkcs11-helper-devel
- Removed libdigidoc++ obsoletes/provides
- Removed R: pkgconfig which is now automatically picked up by rpm
- Added AUTHORS and COPYING docs
- Cleaned up nightly build changelog entries

* Sat Feb 13 2010 Kalev Lember <kalev@smartlink.ee> - 0.2.0-0.4.svn2528
- rebuilt with new xerces-c 3.0 (F13)

* Thu Jan 21 2010 Kalev Lember <kalev@smartlink.ee> - 0.2.0-0.2.svn2454
- rebuilt with new libp11

* Sun Jun 14 2009 Kalev Lember <kalev@smartlink.ee> - 0.0.12-0.1.svn712
- Initial RPM release.
